# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UserAssessmentSummary(object):
    """
    The summary of the user assessment.
    """

    #: A constant which can be used with the lifecycle_state property of a UserAssessmentSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a UserAssessmentSummary.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a UserAssessmentSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a UserAssessmentSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a UserAssessmentSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the triggered_by property of a UserAssessmentSummary.
    #: This constant has a value of "USER"
    TRIGGERED_BY_USER = "USER"

    #: A constant which can be used with the triggered_by property of a UserAssessmentSummary.
    #: This constant has a value of "SYSTEM"
    TRIGGERED_BY_SYSTEM = "SYSTEM"

    #: A constant which can be used with the type property of a UserAssessmentSummary.
    #: This constant has a value of "LATEST"
    TYPE_LATEST = "LATEST"

    #: A constant which can be used with the type property of a UserAssessmentSummary.
    #: This constant has a value of "SAVED"
    TYPE_SAVED = "SAVED"

    #: A constant which can be used with the type property of a UserAssessmentSummary.
    #: This constant has a value of "SAVE_SCHEDULE"
    TYPE_SAVE_SCHEDULE = "SAVE_SCHEDULE"

    #: A constant which can be used with the type property of a UserAssessmentSummary.
    #: This constant has a value of "COMPARTMENT"
    TYPE_COMPARTMENT = "COMPARTMENT"

    def __init__(self, **kwargs):
        """
        Initializes a new UserAssessmentSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this UserAssessmentSummary.
        :type compartment_id: str

        :param description:
            The value to assign to the description property of this UserAssessmentSummary.
        :type description: str

        :param display_name:
            The value to assign to the display_name property of this UserAssessmentSummary.
        :type display_name: str

        :param id:
            The value to assign to the id property of this UserAssessmentSummary.
        :type id: str

        :param ignored_targets:
            The value to assign to the ignored_targets property of this UserAssessmentSummary.
        :type ignored_targets: list[object]

        :param ignored_assessment_ids:
            The value to assign to the ignored_assessment_ids property of this UserAssessmentSummary.
        :type ignored_assessment_ids: list[object]

        :param is_baseline:
            The value to assign to the is_baseline property of this UserAssessmentSummary.
        :type is_baseline: bool

        :param is_deviated_from_baseline:
            The value to assign to the is_deviated_from_baseline property of this UserAssessmentSummary.
        :type is_deviated_from_baseline: bool

        :param last_compared_baseline_id:
            The value to assign to the last_compared_baseline_id property of this UserAssessmentSummary.
        :type last_compared_baseline_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this UserAssessmentSummary.
            Allowed values for this property are: "CREATING", "SUCCEEDED", "UPDATING", "DELETING", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this UserAssessmentSummary.
        :type lifecycle_details: str

        :param schedule_assessment_id:
            The value to assign to the schedule_assessment_id property of this UserAssessmentSummary.
        :type schedule_assessment_id: str

        :param schedule:
            The value to assign to the schedule property of this UserAssessmentSummary.
        :type schedule: str

        :param statistics:
            The value to assign to the statistics property of this UserAssessmentSummary.
        :type statistics: dict(str, dict(str, object))

        :param target_ids:
            The value to assign to the target_ids property of this UserAssessmentSummary.
        :type target_ids: list[str]

        :param time_created:
            The value to assign to the time_created property of this UserAssessmentSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this UserAssessmentSummary.
        :type time_updated: datetime

        :param triggered_by:
            The value to assign to the triggered_by property of this UserAssessmentSummary.
            Allowed values for this property are: "USER", "SYSTEM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type triggered_by: str

        :param type:
            The value to assign to the type property of this UserAssessmentSummary.
            Allowed values for this property are: "LATEST", "SAVED", "SAVE_SCHEDULE", "COMPARTMENT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UserAssessmentSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UserAssessmentSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'description': 'str',
            'display_name': 'str',
            'id': 'str',
            'ignored_targets': 'list[object]',
            'ignored_assessment_ids': 'list[object]',
            'is_baseline': 'bool',
            'is_deviated_from_baseline': 'bool',
            'last_compared_baseline_id': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'schedule_assessment_id': 'str',
            'schedule': 'str',
            'statistics': 'dict(str, dict(str, object))',
            'target_ids': 'list[str]',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'triggered_by': 'str',
            'type': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'description': 'description',
            'display_name': 'displayName',
            'id': 'id',
            'ignored_targets': 'ignoredTargets',
            'ignored_assessment_ids': 'ignoredAssessmentIds',
            'is_baseline': 'isBaseline',
            'is_deviated_from_baseline': 'isDeviatedFromBaseline',
            'last_compared_baseline_id': 'lastComparedBaselineId',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'schedule_assessment_id': 'scheduleAssessmentId',
            'schedule': 'schedule',
            'statistics': 'statistics',
            'target_ids': 'targetIds',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'triggered_by': 'triggeredBy',
            'type': 'type',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._description = None
        self._display_name = None
        self._id = None
        self._ignored_targets = None
        self._ignored_assessment_ids = None
        self._is_baseline = None
        self._is_deviated_from_baseline = None
        self._last_compared_baseline_id = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._schedule_assessment_id = None
        self._schedule = None
        self._statistics = None
        self._target_ids = None
        self._time_created = None
        self._time_updated = None
        self._triggered_by = None
        self._type = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this UserAssessmentSummary.
        The OCID of the compartment that contains the user assessment.


        :return: The compartment_id of this UserAssessmentSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this UserAssessmentSummary.
        The OCID of the compartment that contains the user assessment.


        :param compartment_id: The compartment_id of this UserAssessmentSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def description(self):
        """
        Gets the description of this UserAssessmentSummary.
        The description of the user assessment.


        :return: The description of this UserAssessmentSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UserAssessmentSummary.
        The description of the user assessment.


        :param description: The description of this UserAssessmentSummary.
        :type: str
        """
        self._description = description

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this UserAssessmentSummary.
        The display name of the user assessment.


        :return: The display_name of this UserAssessmentSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UserAssessmentSummary.
        The display name of the user assessment.


        :param display_name: The display_name of this UserAssessmentSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def id(self):
        """
        **[Required]** Gets the id of this UserAssessmentSummary.
        The OCID of the user assessment.


        :return: The id of this UserAssessmentSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this UserAssessmentSummary.
        The OCID of the user assessment.


        :param id: The id of this UserAssessmentSummary.
        :type: str
        """
        self._id = id

    @property
    def ignored_targets(self):
        """
        Gets the ignored_targets of this UserAssessmentSummary.
        List containing maps as values.
        Example: `{\"Operations\": [ {\"CostCenter\": \"42\"} ] }`


        :return: The ignored_targets of this UserAssessmentSummary.
        :rtype: list[object]
        """
        return self._ignored_targets

    @ignored_targets.setter
    def ignored_targets(self, ignored_targets):
        """
        Sets the ignored_targets of this UserAssessmentSummary.
        List containing maps as values.
        Example: `{\"Operations\": [ {\"CostCenter\": \"42\"} ] }`


        :param ignored_targets: The ignored_targets of this UserAssessmentSummary.
        :type: list[object]
        """
        self._ignored_targets = ignored_targets

    @property
    def ignored_assessment_ids(self):
        """
        Gets the ignored_assessment_ids of this UserAssessmentSummary.
        List containing maps as values.
        Example: `{\"Operations\": [ {\"CostCenter\": \"42\"} ] }`


        :return: The ignored_assessment_ids of this UserAssessmentSummary.
        :rtype: list[object]
        """
        return self._ignored_assessment_ids

    @ignored_assessment_ids.setter
    def ignored_assessment_ids(self, ignored_assessment_ids):
        """
        Sets the ignored_assessment_ids of this UserAssessmentSummary.
        List containing maps as values.
        Example: `{\"Operations\": [ {\"CostCenter\": \"42\"} ] }`


        :param ignored_assessment_ids: The ignored_assessment_ids of this UserAssessmentSummary.
        :type: list[object]
        """
        self._ignored_assessment_ids = ignored_assessment_ids

    @property
    def is_baseline(self):
        """
        Gets the is_baseline of this UserAssessmentSummary.
        Indicates if the assessment is a baseline assessment. This applies to saved user assessments only.


        :return: The is_baseline of this UserAssessmentSummary.
        :rtype: bool
        """
        return self._is_baseline

    @is_baseline.setter
    def is_baseline(self, is_baseline):
        """
        Sets the is_baseline of this UserAssessmentSummary.
        Indicates if the assessment is a baseline assessment. This applies to saved user assessments only.


        :param is_baseline: The is_baseline of this UserAssessmentSummary.
        :type: bool
        """
        self._is_baseline = is_baseline

    @property
    def is_deviated_from_baseline(self):
        """
        Gets the is_deviated_from_baseline of this UserAssessmentSummary.
        Indicates if the assessment has deviated from the baseline.


        :return: The is_deviated_from_baseline of this UserAssessmentSummary.
        :rtype: bool
        """
        return self._is_deviated_from_baseline

    @is_deviated_from_baseline.setter
    def is_deviated_from_baseline(self, is_deviated_from_baseline):
        """
        Sets the is_deviated_from_baseline of this UserAssessmentSummary.
        Indicates if the assessment has deviated from the baseline.


        :param is_deviated_from_baseline: The is_deviated_from_baseline of this UserAssessmentSummary.
        :type: bool
        """
        self._is_deviated_from_baseline = is_deviated_from_baseline

    @property
    def last_compared_baseline_id(self):
        """
        Gets the last_compared_baseline_id of this UserAssessmentSummary.
        The OCID of the last user assessment baseline against which the latest assessment was compared.


        :return: The last_compared_baseline_id of this UserAssessmentSummary.
        :rtype: str
        """
        return self._last_compared_baseline_id

    @last_compared_baseline_id.setter
    def last_compared_baseline_id(self, last_compared_baseline_id):
        """
        Sets the last_compared_baseline_id of this UserAssessmentSummary.
        The OCID of the last user assessment baseline against which the latest assessment was compared.


        :param last_compared_baseline_id: The last_compared_baseline_id of this UserAssessmentSummary.
        :type: str
        """
        self._last_compared_baseline_id = last_compared_baseline_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this UserAssessmentSummary.
        The current state of the user assessment.

        Allowed values for this property are: "CREATING", "SUCCEEDED", "UPDATING", "DELETING", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this UserAssessmentSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this UserAssessmentSummary.
        The current state of the user assessment.


        :param lifecycle_state: The lifecycle_state of this UserAssessmentSummary.
        :type: str
        """
        allowed_values = ["CREATING", "SUCCEEDED", "UPDATING", "DELETING", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this UserAssessmentSummary.
        Details about the current state of the user assessment.


        :return: The lifecycle_details of this UserAssessmentSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this UserAssessmentSummary.
        Details about the current state of the user assessment.


        :param lifecycle_details: The lifecycle_details of this UserAssessmentSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def schedule_assessment_id(self):
        """
        Gets the schedule_assessment_id of this UserAssessmentSummary.
        The OCID of the user assessment that created this scheduled save assessment.


        :return: The schedule_assessment_id of this UserAssessmentSummary.
        :rtype: str
        """
        return self._schedule_assessment_id

    @schedule_assessment_id.setter
    def schedule_assessment_id(self, schedule_assessment_id):
        """
        Sets the schedule_assessment_id of this UserAssessmentSummary.
        The OCID of the user assessment that created this scheduled save assessment.


        :param schedule_assessment_id: The schedule_assessment_id of this UserAssessmentSummary.
        :type: str
        """
        self._schedule_assessment_id = schedule_assessment_id

    @property
    def schedule(self):
        """
        Gets the schedule of this UserAssessmentSummary.
        Schedule to save the assessment periodically in the specified format:
        <version-string>;<version-specific-schedule>

        Allowed version strings - \"v1\"
        v1's version specific schedule -<ss> <mm> <hh> <day-of-week> <day-of-month>
        Each of the above fields potentially introduce constraints. A workrequest is created only
        when clock time satisfies all the constraints. Constraints introduced:
        1. seconds = <ss> (So, the allowed range for <ss> is [0, 59])
        2. minutes = <mm> (So, the allowed range for <mm> is [0, 59])
        3. hours = <hh> (So, the allowed range for <hh> is [0, 23])
        <day-of-week> can be either '*' (without quotes or a number between 1(Monday) and 7(Sunday))
        4. No constraint introduced when it is '*'. When not, day of week must equal the given value
        <day-of-month> can be either '*' (without quotes or a number between 1 and 28)
        5. No constraint introduced when it is '*'. When not, day of month must equal the given value


        :return: The schedule of this UserAssessmentSummary.
        :rtype: str
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """
        Sets the schedule of this UserAssessmentSummary.
        Schedule to save the assessment periodically in the specified format:
        <version-string>;<version-specific-schedule>

        Allowed version strings - \"v1\"
        v1's version specific schedule -<ss> <mm> <hh> <day-of-week> <day-of-month>
        Each of the above fields potentially introduce constraints. A workrequest is created only
        when clock time satisfies all the constraints. Constraints introduced:
        1. seconds = <ss> (So, the allowed range for <ss> is [0, 59])
        2. minutes = <mm> (So, the allowed range for <mm> is [0, 59])
        3. hours = <hh> (So, the allowed range for <hh> is [0, 23])
        <day-of-week> can be either '*' (without quotes or a number between 1(Monday) and 7(Sunday))
        4. No constraint introduced when it is '*'. When not, day of week must equal the given value
        <day-of-month> can be either '*' (without quotes or a number between 1 and 28)
        5. No constraint introduced when it is '*'. When not, day of month must equal the given value


        :param schedule: The schedule of this UserAssessmentSummary.
        :type: str
        """
        self._schedule = schedule

    @property
    def statistics(self):
        """
        Gets the statistics of this UserAssessmentSummary.
        Map that contains maps of values.
         Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`


        :return: The statistics of this UserAssessmentSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._statistics

    @statistics.setter
    def statistics(self, statistics):
        """
        Sets the statistics of this UserAssessmentSummary.
        Map that contains maps of values.
         Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`


        :param statistics: The statistics of this UserAssessmentSummary.
        :type: dict(str, dict(str, object))
        """
        self._statistics = statistics

    @property
    def target_ids(self):
        """
        Gets the target_ids of this UserAssessmentSummary.
        Array of database target OCIDs.


        :return: The target_ids of this UserAssessmentSummary.
        :rtype: list[str]
        """
        return self._target_ids

    @target_ids.setter
    def target_ids(self, target_ids):
        """
        Sets the target_ids of this UserAssessmentSummary.
        Array of database target OCIDs.


        :param target_ids: The target_ids of this UserAssessmentSummary.
        :type: list[str]
        """
        self._target_ids = target_ids

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this UserAssessmentSummary.
        The date and time when the user assessment was created, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this UserAssessmentSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this UserAssessmentSummary.
        The date and time when the user assessment was created, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this UserAssessmentSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this UserAssessmentSummary.
        The last date and time when the user assessment was updated, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this UserAssessmentSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this UserAssessmentSummary.
        The last date and time when the user assessment was updated, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this UserAssessmentSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def triggered_by(self):
        """
        Gets the triggered_by of this UserAssessmentSummary.
        Indicates whether the user assessment was created by system or user.

        Allowed values for this property are: "USER", "SYSTEM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The triggered_by of this UserAssessmentSummary.
        :rtype: str
        """
        return self._triggered_by

    @triggered_by.setter
    def triggered_by(self, triggered_by):
        """
        Sets the triggered_by of this UserAssessmentSummary.
        Indicates whether the user assessment was created by system or user.


        :param triggered_by: The triggered_by of this UserAssessmentSummary.
        :type: str
        """
        allowed_values = ["USER", "SYSTEM"]
        if not value_allowed_none_or_none_sentinel(triggered_by, allowed_values):
            triggered_by = 'UNKNOWN_ENUM_VALUE'
        self._triggered_by = triggered_by

    @property
    def type(self):
        """
        **[Required]** Gets the type of this UserAssessmentSummary.
        Type of user assessment. The possible types are:

        LATEST: The most up-to-date assessment that is running automatically for a target. It is system generated.
        SAVED: A saved user assessment. LATEST assessments are always saved to maintain the history of runs. A SAVED assessment is also generated by a 'refresh' action (triggered by the user).
        SAVE_SCHEDULE: The schedule for periodic save of LATEST assessments.
        COMPARTMENT: An automatic managed assessment type that stores all details of targets in one compartment. This type keeps an up-to-date status of all database risks in one compartment.
               It is automatically updated when the latest assessment or refresh action is executed. It is also automatically updated when a target is deleted or move to a different compartment.

        Allowed values for this property are: "LATEST", "SAVED", "SAVE_SCHEDULE", "COMPARTMENT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this UserAssessmentSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this UserAssessmentSummary.
        Type of user assessment. The possible types are:

        LATEST: The most up-to-date assessment that is running automatically for a target. It is system generated.
        SAVED: A saved user assessment. LATEST assessments are always saved to maintain the history of runs. A SAVED assessment is also generated by a 'refresh' action (triggered by the user).
        SAVE_SCHEDULE: The schedule for periodic save of LATEST assessments.
        COMPARTMENT: An automatic managed assessment type that stores all details of targets in one compartment. This type keeps an up-to-date status of all database risks in one compartment.
               It is automatically updated when the latest assessment or refresh action is executed. It is also automatically updated when a target is deleted or move to a different compartment.


        :param type: The type of this UserAssessmentSummary.
        :type: str
        """
        allowed_values = ["LATEST", "SAVED", "SAVE_SCHEDULE", "COMPARTMENT"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UserAssessmentSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UserAssessmentSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UserAssessmentSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UserAssessmentSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UserAssessmentSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UserAssessmentSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UserAssessmentSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UserAssessmentSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DeployPluginsDetails(object):
    """
    The information required to deploy new Management Agent Plugins.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DeployPluginsDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param plugin_ids:
            The value to assign to the plugin_ids property of this DeployPluginsDetails.
        :type plugin_ids: list[str]

        :param agent_compartment_id:
            The value to assign to the agent_compartment_id property of this DeployPluginsDetails.
        :type agent_compartment_id: str

        :param agent_ids:
            The value to assign to the agent_ids property of this DeployPluginsDetails.
        :type agent_ids: list[str]

        """
        self.swagger_types = {
            'plugin_ids': 'list[str]',
            'agent_compartment_id': 'str',
            'agent_ids': 'list[str]'
        }

        self.attribute_map = {
            'plugin_ids': 'pluginIds',
            'agent_compartment_id': 'agentCompartmentId',
            'agent_ids': 'agentIds'
        }

        self._plugin_ids = None
        self._agent_compartment_id = None
        self._agent_ids = None

    @property
    def plugin_ids(self):
        """
        **[Required]** Gets the plugin_ids of this DeployPluginsDetails.
        Plugin Id


        :return: The plugin_ids of this DeployPluginsDetails.
        :rtype: list[str]
        """
        return self._plugin_ids

    @plugin_ids.setter
    def plugin_ids(self, plugin_ids):
        """
        Sets the plugin_ids of this DeployPluginsDetails.
        Plugin Id


        :param plugin_ids: The plugin_ids of this DeployPluginsDetails.
        :type: list[str]
        """
        self._plugin_ids = plugin_ids

    @property
    def agent_compartment_id(self):
        """
        **[Required]** Gets the agent_compartment_id of this DeployPluginsDetails.
        Management Agent Compartment Identifier


        :return: The agent_compartment_id of this DeployPluginsDetails.
        :rtype: str
        """
        return self._agent_compartment_id

    @agent_compartment_id.setter
    def agent_compartment_id(self, agent_compartment_id):
        """
        Sets the agent_compartment_id of this DeployPluginsDetails.
        Management Agent Compartment Identifier


        :param agent_compartment_id: The agent_compartment_id of this DeployPluginsDetails.
        :type: str
        """
        self._agent_compartment_id = agent_compartment_id

    @property
    def agent_ids(self):
        """
        **[Required]** Gets the agent_ids of this DeployPluginsDetails.
        List of Agent identifiers


        :return: The agent_ids of this DeployPluginsDetails.
        :rtype: list[str]
        """
        return self._agent_ids

    @agent_ids.setter
    def agent_ids(self, agent_ids):
        """
        Sets the agent_ids of this DeployPluginsDetails.
        List of Agent identifiers


        :param agent_ids: The agent_ids of this DeployPluginsDetails.
        :type: list[str]
        """
        self._agent_ids = agent_ids

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsLookupFields(object):
    """
    LogAnalyticsLookupFields
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsLookupFields object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param common_field_name:
            The value to assign to the common_field_name property of this LogAnalyticsLookupFields.
        :type common_field_name: str

        :param default_match_value:
            The value to assign to the default_match_value property of this LogAnalyticsLookupFields.
        :type default_match_value: str

        :param display_name:
            The value to assign to the display_name property of this LogAnalyticsLookupFields.
        :type display_name: str

        :param is_common_field:
            The value to assign to the is_common_field property of this LogAnalyticsLookupFields.
        :type is_common_field: bool

        :param match_operator:
            The value to assign to the match_operator property of this LogAnalyticsLookupFields.
        :type match_operator: str

        :param name:
            The value to assign to the name property of this LogAnalyticsLookupFields.
        :type name: str

        :param position:
            The value to assign to the position property of this LogAnalyticsLookupFields.
        :type position: int

        """
        self.swagger_types = {
            'common_field_name': 'str',
            'default_match_value': 'str',
            'display_name': 'str',
            'is_common_field': 'bool',
            'match_operator': 'str',
            'name': 'str',
            'position': 'int'
        }

        self.attribute_map = {
            'common_field_name': 'commonFieldName',
            'default_match_value': 'defaultMatchValue',
            'display_name': 'displayName',
            'is_common_field': 'isCommonField',
            'match_operator': 'matchOperator',
            'name': 'name',
            'position': 'position'
        }

        self._common_field_name = None
        self._default_match_value = None
        self._display_name = None
        self._is_common_field = None
        self._match_operator = None
        self._name = None
        self._position = None

    @property
    def common_field_name(self):
        """
        Gets the common_field_name of this LogAnalyticsLookupFields.
        The common field name.


        :return: The common_field_name of this LogAnalyticsLookupFields.
        :rtype: str
        """
        return self._common_field_name

    @common_field_name.setter
    def common_field_name(self, common_field_name):
        """
        Sets the common_field_name of this LogAnalyticsLookupFields.
        The common field name.


        :param common_field_name: The common_field_name of this LogAnalyticsLookupFields.
        :type: str
        """
        self._common_field_name = common_field_name

    @property
    def default_match_value(self):
        """
        Gets the default_match_value of this LogAnalyticsLookupFields.
        The default match value.


        :return: The default_match_value of this LogAnalyticsLookupFields.
        :rtype: str
        """
        return self._default_match_value

    @default_match_value.setter
    def default_match_value(self, default_match_value):
        """
        Sets the default_match_value of this LogAnalyticsLookupFields.
        The default match value.


        :param default_match_value: The default_match_value of this LogAnalyticsLookupFields.
        :type: str
        """
        self._default_match_value = default_match_value

    @property
    def display_name(self):
        """
        Gets the display_name of this LogAnalyticsLookupFields.
        The display name.


        :return: The display_name of this LogAnalyticsLookupFields.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this LogAnalyticsLookupFields.
        The display name.


        :param display_name: The display_name of this LogAnalyticsLookupFields.
        :type: str
        """
        self._display_name = display_name

    @property
    def is_common_field(self):
        """
        Gets the is_common_field of this LogAnalyticsLookupFields.
        A flag indicating whether or not the field is a common field.


        :return: The is_common_field of this LogAnalyticsLookupFields.
        :rtype: bool
        """
        return self._is_common_field

    @is_common_field.setter
    def is_common_field(self, is_common_field):
        """
        Sets the is_common_field of this LogAnalyticsLookupFields.
        A flag indicating whether or not the field is a common field.


        :param is_common_field: The is_common_field of this LogAnalyticsLookupFields.
        :type: bool
        """
        self._is_common_field = is_common_field

    @property
    def match_operator(self):
        """
        Gets the match_operator of this LogAnalyticsLookupFields.
        The match operator.


        :return: The match_operator of this LogAnalyticsLookupFields.
        :rtype: str
        """
        return self._match_operator

    @match_operator.setter
    def match_operator(self, match_operator):
        """
        Sets the match_operator of this LogAnalyticsLookupFields.
        The match operator.


        :param match_operator: The match_operator of this LogAnalyticsLookupFields.
        :type: str
        """
        self._match_operator = match_operator

    @property
    def name(self):
        """
        Gets the name of this LogAnalyticsLookupFields.
        The field name.


        :return: The name of this LogAnalyticsLookupFields.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LogAnalyticsLookupFields.
        The field name.


        :param name: The name of this LogAnalyticsLookupFields.
        :type: str
        """
        self._name = name

    @property
    def position(self):
        """
        Gets the position of this LogAnalyticsLookupFields.
        The position.


        :return: The position of this LogAnalyticsLookupFields.
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        """
        Sets the position of this LogAnalyticsLookupFields.
        The position.


        :param position: The position of this LogAnalyticsLookupFields.
        :type: int
        """
        self._position = position

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateBudgetDetails(object):
    """
    The create budget details.

    Client should use 'targetType' & 'targets' to specify the target type and list of targets on which the budget is applied.

    For backwards compatibility, 'targetCompartmentId' will still be supported for all existing clients.
    However, this is considered deprecreated and all clients be upgraded to use 'targetType' & 'targets'.

    Specifying both 'targetCompartmentId' and 'targets' will cause a Bad Request.
    """

    #: A constant which can be used with the reset_period property of a CreateBudgetDetails.
    #: This constant has a value of "MONTHLY"
    RESET_PERIOD_MONTHLY = "MONTHLY"

    #: A constant which can be used with the target_type property of a CreateBudgetDetails.
    #: This constant has a value of "COMPARTMENT"
    TARGET_TYPE_COMPARTMENT = "COMPARTMENT"

    #: A constant which can be used with the target_type property of a CreateBudgetDetails.
    #: This constant has a value of "TAG"
    TARGET_TYPE_TAG = "TAG"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateBudgetDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateBudgetDetails.
        :type compartment_id: str

        :param target_compartment_id:
            The value to assign to the target_compartment_id property of this CreateBudgetDetails.
        :type target_compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this CreateBudgetDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateBudgetDetails.
        :type description: str

        :param amount:
            The value to assign to the amount property of this CreateBudgetDetails.
        :type amount: float

        :param reset_period:
            The value to assign to the reset_period property of this CreateBudgetDetails.
            Allowed values for this property are: "MONTHLY"
        :type reset_period: str

        :param budget_processing_period_start_offset:
            The value to assign to the budget_processing_period_start_offset property of this CreateBudgetDetails.
        :type budget_processing_period_start_offset: int

        :param target_type:
            The value to assign to the target_type property of this CreateBudgetDetails.
            Allowed values for this property are: "COMPARTMENT", "TAG"
        :type target_type: str

        :param targets:
            The value to assign to the targets property of this CreateBudgetDetails.
        :type targets: list[str]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateBudgetDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateBudgetDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'target_compartment_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'amount': 'float',
            'reset_period': 'str',
            'budget_processing_period_start_offset': 'int',
            'target_type': 'str',
            'targets': 'list[str]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'target_compartment_id': 'targetCompartmentId',
            'display_name': 'displayName',
            'description': 'description',
            'amount': 'amount',
            'reset_period': 'resetPeriod',
            'budget_processing_period_start_offset': 'budgetProcessingPeriodStartOffset',
            'target_type': 'targetType',
            'targets': 'targets',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._target_compartment_id = None
        self._display_name = None
        self._description = None
        self._amount = None
        self._reset_period = None
        self._budget_processing_period_start_offset = None
        self._target_type = None
        self._targets = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateBudgetDetails.
        The OCID of the compartment


        :return: The compartment_id of this CreateBudgetDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateBudgetDetails.
        The OCID of the compartment


        :param compartment_id: The compartment_id of this CreateBudgetDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def target_compartment_id(self):
        """
        Gets the target_compartment_id of this CreateBudgetDetails.
        This is DEPRECTAED. Set the target compartment id in targets instead.


        :return: The target_compartment_id of this CreateBudgetDetails.
        :rtype: str
        """
        return self._target_compartment_id

    @target_compartment_id.setter
    def target_compartment_id(self, target_compartment_id):
        """
        Sets the target_compartment_id of this CreateBudgetDetails.
        This is DEPRECTAED. Set the target compartment id in targets instead.


        :param target_compartment_id: The target_compartment_id of this CreateBudgetDetails.
        :type: str
        """
        self._target_compartment_id = target_compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateBudgetDetails.
        The displayName of the budget.


        :return: The display_name of this CreateBudgetDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateBudgetDetails.
        The displayName of the budget.


        :param display_name: The display_name of this CreateBudgetDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateBudgetDetails.
        The description of the budget.


        :return: The description of this CreateBudgetDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateBudgetDetails.
        The description of the budget.


        :param description: The description of this CreateBudgetDetails.
        :type: str
        """
        self._description = description

    @property
    def amount(self):
        """
        **[Required]** Gets the amount of this CreateBudgetDetails.
        The amount of the budget expressed as a whole number in the currency of the customer's rate card.


        :return: The amount of this CreateBudgetDetails.
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """
        Sets the amount of this CreateBudgetDetails.
        The amount of the budget expressed as a whole number in the currency of the customer's rate card.


        :param amount: The amount of this CreateBudgetDetails.
        :type: float
        """
        self._amount = amount

    @property
    def reset_period(self):
        """
        **[Required]** Gets the reset_period of this CreateBudgetDetails.
        The reset period for the budget.

        Allowed values for this property are: "MONTHLY"


        :return: The reset_period of this CreateBudgetDetails.
        :rtype: str
        """
        return self._reset_period

    @reset_period.setter
    def reset_period(self, reset_period):
        """
        Sets the reset_period of this CreateBudgetDetails.
        The reset period for the budget.


        :param reset_period: The reset_period of this CreateBudgetDetails.
        :type: str
        """
        allowed_values = ["MONTHLY"]
        if not value_allowed_none_or_none_sentinel(reset_period, allowed_values):
            raise ValueError(
                "Invalid value for `reset_period`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._reset_period = reset_period

    @property
    def budget_processing_period_start_offset(self):
        """
        Gets the budget_processing_period_start_offset of this CreateBudgetDetails.
        The number of days offset from the first day of the month, at which the budget processing period starts. In months that have fewer days than this value, processing will begin on the last day of that month. For example, for a value of 12, processing starts every month on the 12th at midnight.


        :return: The budget_processing_period_start_offset of this CreateBudgetDetails.
        :rtype: int
        """
        return self._budget_processing_period_start_offset

    @budget_processing_period_start_offset.setter
    def budget_processing_period_start_offset(self, budget_processing_period_start_offset):
        """
        Sets the budget_processing_period_start_offset of this CreateBudgetDetails.
        The number of days offset from the first day of the month, at which the budget processing period starts. In months that have fewer days than this value, processing will begin on the last day of that month. For example, for a value of 12, processing starts every month on the 12th at midnight.


        :param budget_processing_period_start_offset: The budget_processing_period_start_offset of this CreateBudgetDetails.
        :type: int
        """
        self._budget_processing_period_start_offset = budget_processing_period_start_offset

    @property
    def target_type(self):
        """
        Gets the target_type of this CreateBudgetDetails.
        The type of target on which the budget is applied.

        Allowed values for this property are: "COMPARTMENT", "TAG"


        :return: The target_type of this CreateBudgetDetails.
        :rtype: str
        """
        return self._target_type

    @target_type.setter
    def target_type(self, target_type):
        """
        Sets the target_type of this CreateBudgetDetails.
        The type of target on which the budget is applied.


        :param target_type: The target_type of this CreateBudgetDetails.
        :type: str
        """
        allowed_values = ["COMPARTMENT", "TAG"]
        if not value_allowed_none_or_none_sentinel(target_type, allowed_values):
            raise ValueError(
                "Invalid value for `target_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._target_type = target_type

    @property
    def targets(self):
        """
        Gets the targets of this CreateBudgetDetails.
        The list of targets on which the budget is applied.
          If targetType is \"COMPARTMENT\", targets contains list of compartment OCIDs.
          If targetType is \"TAG\", targets contains list of cost tracking tag identifiers in the form of \"{tagNamespace}.{tagKey}.{tagValue}\".
        Curerntly, the array should contain EXACT ONE item.


        :return: The targets of this CreateBudgetDetails.
        :rtype: list[str]
        """
        return self._targets

    @targets.setter
    def targets(self, targets):
        """
        Sets the targets of this CreateBudgetDetails.
        The list of targets on which the budget is applied.
          If targetType is \"COMPARTMENT\", targets contains list of compartment OCIDs.
          If targetType is \"TAG\", targets contains list of cost tracking tag identifiers in the form of \"{tagNamespace}.{tagKey}.{tagValue}\".
        Curerntly, the array should contain EXACT ONE item.


        :param targets: The targets of this CreateBudgetDetails.
        :type: list[str]
        """
        self._targets = targets

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateBudgetDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateBudgetDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateBudgetDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateBudgetDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateBudgetDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateBudgetDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateBudgetDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateBudgetDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DbBackupConfig(object):
    """
    Backup Options
    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the auto_backup_window property of a DbBackupConfig.
    #: This constant has a value of "SLOT_ONE"
    AUTO_BACKUP_WINDOW_SLOT_ONE = "SLOT_ONE"

    #: A constant which can be used with the auto_backup_window property of a DbBackupConfig.
    #: This constant has a value of "SLOT_TWO"
    AUTO_BACKUP_WINDOW_SLOT_TWO = "SLOT_TWO"

    #: A constant which can be used with the auto_backup_window property of a DbBackupConfig.
    #: This constant has a value of "SLOT_THREE"
    AUTO_BACKUP_WINDOW_SLOT_THREE = "SLOT_THREE"

    #: A constant which can be used with the auto_backup_window property of a DbBackupConfig.
    #: This constant has a value of "SLOT_FOUR"
    AUTO_BACKUP_WINDOW_SLOT_FOUR = "SLOT_FOUR"

    #: A constant which can be used with the auto_backup_window property of a DbBackupConfig.
    #: This constant has a value of "SLOT_FIVE"
    AUTO_BACKUP_WINDOW_SLOT_FIVE = "SLOT_FIVE"

    #: A constant which can be used with the auto_backup_window property of a DbBackupConfig.
    #: This constant has a value of "SLOT_SIX"
    AUTO_BACKUP_WINDOW_SLOT_SIX = "SLOT_SIX"

    #: A constant which can be used with the auto_backup_window property of a DbBackupConfig.
    #: This constant has a value of "SLOT_SEVEN"
    AUTO_BACKUP_WINDOW_SLOT_SEVEN = "SLOT_SEVEN"

    #: A constant which can be used with the auto_backup_window property of a DbBackupConfig.
    #: This constant has a value of "SLOT_EIGHT"
    AUTO_BACKUP_WINDOW_SLOT_EIGHT = "SLOT_EIGHT"

    #: A constant which can be used with the auto_backup_window property of a DbBackupConfig.
    #: This constant has a value of "SLOT_NINE"
    AUTO_BACKUP_WINDOW_SLOT_NINE = "SLOT_NINE"

    #: A constant which can be used with the auto_backup_window property of a DbBackupConfig.
    #: This constant has a value of "SLOT_TEN"
    AUTO_BACKUP_WINDOW_SLOT_TEN = "SLOT_TEN"

    #: A constant which can be used with the auto_backup_window property of a DbBackupConfig.
    #: This constant has a value of "SLOT_ELEVEN"
    AUTO_BACKUP_WINDOW_SLOT_ELEVEN = "SLOT_ELEVEN"

    #: A constant which can be used with the auto_backup_window property of a DbBackupConfig.
    #: This constant has a value of "SLOT_TWELVE"
    AUTO_BACKUP_WINDOW_SLOT_TWELVE = "SLOT_TWELVE"

    def __init__(self, **kwargs):
        """
        Initializes a new DbBackupConfig object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param auto_backup_enabled:
            The value to assign to the auto_backup_enabled property of this DbBackupConfig.
        :type auto_backup_enabled: bool

        :param recovery_window_in_days:
            The value to assign to the recovery_window_in_days property of this DbBackupConfig.
        :type recovery_window_in_days: int

        :param auto_backup_window:
            The value to assign to the auto_backup_window property of this DbBackupConfig.
            Allowed values for this property are: "SLOT_ONE", "SLOT_TWO", "SLOT_THREE", "SLOT_FOUR", "SLOT_FIVE", "SLOT_SIX", "SLOT_SEVEN", "SLOT_EIGHT", "SLOT_NINE", "SLOT_TEN", "SLOT_ELEVEN", "SLOT_TWELVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type auto_backup_window: str

        :param backup_destination_details:
            The value to assign to the backup_destination_details property of this DbBackupConfig.
        :type backup_destination_details: list[oci.database.models.BackupDestinationDetails]

        """
        self.swagger_types = {
            'auto_backup_enabled': 'bool',
            'recovery_window_in_days': 'int',
            'auto_backup_window': 'str',
            'backup_destination_details': 'list[BackupDestinationDetails]'
        }

        self.attribute_map = {
            'auto_backup_enabled': 'autoBackupEnabled',
            'recovery_window_in_days': 'recoveryWindowInDays',
            'auto_backup_window': 'autoBackupWindow',
            'backup_destination_details': 'backupDestinationDetails'
        }

        self._auto_backup_enabled = None
        self._recovery_window_in_days = None
        self._auto_backup_window = None
        self._backup_destination_details = None

    @property
    def auto_backup_enabled(self):
        """
        Gets the auto_backup_enabled of this DbBackupConfig.
        If set to true, configures automatic backups. If you previously used RMAN or dbcli to configure backups and then you switch to using the Console or the API for backups, a new backup configuration is created and associated with your database. This means that you can no longer rely on your previously configured unmanaged backups to work.


        :return: The auto_backup_enabled of this DbBackupConfig.
        :rtype: bool
        """
        return self._auto_backup_enabled

    @auto_backup_enabled.setter
    def auto_backup_enabled(self, auto_backup_enabled):
        """
        Sets the auto_backup_enabled of this DbBackupConfig.
        If set to true, configures automatic backups. If you previously used RMAN or dbcli to configure backups and then you switch to using the Console or the API for backups, a new backup configuration is created and associated with your database. This means that you can no longer rely on your previously configured unmanaged backups to work.


        :param auto_backup_enabled: The auto_backup_enabled of this DbBackupConfig.
        :type: bool
        """
        self._auto_backup_enabled = auto_backup_enabled

    @property
    def recovery_window_in_days(self):
        """
        Gets the recovery_window_in_days of this DbBackupConfig.
        Number of days between the current and the earliest point of recoverability covered by automatic backups.
        This value applies to automatic backups only. After a new automatic backup has been created, Oracle removes old automatic backups that are created before the window.
        When the value is updated, it is applied to all existing automatic backups.


        :return: The recovery_window_in_days of this DbBackupConfig.
        :rtype: int
        """
        return self._recovery_window_in_days

    @recovery_window_in_days.setter
    def recovery_window_in_days(self, recovery_window_in_days):
        """
        Sets the recovery_window_in_days of this DbBackupConfig.
        Number of days between the current and the earliest point of recoverability covered by automatic backups.
        This value applies to automatic backups only. After a new automatic backup has been created, Oracle removes old automatic backups that are created before the window.
        When the value is updated, it is applied to all existing automatic backups.


        :param recovery_window_in_days: The recovery_window_in_days of this DbBackupConfig.
        :type: int
        """
        self._recovery_window_in_days = recovery_window_in_days

    @property
    def auto_backup_window(self):
        """
        Gets the auto_backup_window of this DbBackupConfig.
        Time window selected for initiating automatic backup for the database system. There are twelve available two-hour time windows. If no option is selected, a start time between 12:00 AM to 7:00 AM in the region of the database is automatically chosen. For example, if the user selects SLOT_TWO from the enum list, the automatic backup job will start in between 2:00 AM (inclusive) to 4:00 AM (exclusive).

        Example: `SLOT_TWO`

        Allowed values for this property are: "SLOT_ONE", "SLOT_TWO", "SLOT_THREE", "SLOT_FOUR", "SLOT_FIVE", "SLOT_SIX", "SLOT_SEVEN", "SLOT_EIGHT", "SLOT_NINE", "SLOT_TEN", "SLOT_ELEVEN", "SLOT_TWELVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The auto_backup_window of this DbBackupConfig.
        :rtype: str
        """
        return self._auto_backup_window

    @auto_backup_window.setter
    def auto_backup_window(self, auto_backup_window):
        """
        Sets the auto_backup_window of this DbBackupConfig.
        Time window selected for initiating automatic backup for the database system. There are twelve available two-hour time windows. If no option is selected, a start time between 12:00 AM to 7:00 AM in the region of the database is automatically chosen. For example, if the user selects SLOT_TWO from the enum list, the automatic backup job will start in between 2:00 AM (inclusive) to 4:00 AM (exclusive).

        Example: `SLOT_TWO`


        :param auto_backup_window: The auto_backup_window of this DbBackupConfig.
        :type: str
        """
        allowed_values = ["SLOT_ONE", "SLOT_TWO", "SLOT_THREE", "SLOT_FOUR", "SLOT_FIVE", "SLOT_SIX", "SLOT_SEVEN", "SLOT_EIGHT", "SLOT_NINE", "SLOT_TEN", "SLOT_ELEVEN", "SLOT_TWELVE"]
        if not value_allowed_none_or_none_sentinel(auto_backup_window, allowed_values):
            auto_backup_window = 'UNKNOWN_ENUM_VALUE'
        self._auto_backup_window = auto_backup_window

    @property
    def backup_destination_details(self):
        """
        Gets the backup_destination_details of this DbBackupConfig.
        Backup destination details.


        :return: The backup_destination_details of this DbBackupConfig.
        :rtype: list[oci.database.models.BackupDestinationDetails]
        """
        return self._backup_destination_details

    @backup_destination_details.setter
    def backup_destination_details(self, backup_destination_details):
        """
        Sets the backup_destination_details of this DbBackupConfig.
        Backup destination details.


        :param backup_destination_details: The backup_destination_details of this DbBackupConfig.
        :type: list[oci.database.models.BackupDestinationDetails]
        """
        self._backup_destination_details = backup_destination_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .action import Action
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StreamAction(Action):
    """
    Stream action for scheduled task.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new StreamAction object with values from keyword arguments. The default value of the :py:attr:`~oci.log_analytics.models.StreamAction.type` attribute
        of this class is ``STREAM`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this StreamAction.
            Allowed values for this property are: "STREAM", "PURGE"
        :type type: str

        :param saved_search_id:
            The value to assign to the saved_search_id property of this StreamAction.
        :type saved_search_id: str

        :param metric_extraction:
            The value to assign to the metric_extraction property of this StreamAction.
        :type metric_extraction: oci.log_analytics.models.MetricExtraction

        :param saved_search_duration:
            The value to assign to the saved_search_duration property of this StreamAction.
        :type saved_search_duration: str

        """
        self.swagger_types = {
            'type': 'str',
            'saved_search_id': 'str',
            'metric_extraction': 'MetricExtraction',
            'saved_search_duration': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'saved_search_id': 'savedSearchId',
            'metric_extraction': 'metricExtraction',
            'saved_search_duration': 'savedSearchDuration'
        }

        self._type = None
        self._saved_search_id = None
        self._metric_extraction = None
        self._saved_search_duration = None
        self._type = 'STREAM'

    @property
    def saved_search_id(self):
        """
        Gets the saved_search_id of this StreamAction.
        The ManagementSavedSearch id [OCID] utilized in the action.


        :return: The saved_search_id of this StreamAction.
        :rtype: str
        """
        return self._saved_search_id

    @saved_search_id.setter
    def saved_search_id(self, saved_search_id):
        """
        Sets the saved_search_id of this StreamAction.
        The ManagementSavedSearch id [OCID] utilized in the action.


        :param saved_search_id: The saved_search_id of this StreamAction.
        :type: str
        """
        self._saved_search_id = saved_search_id

    @property
    def metric_extraction(self):
        """
        Gets the metric_extraction of this StreamAction.

        :return: The metric_extraction of this StreamAction.
        :rtype: oci.log_analytics.models.MetricExtraction
        """
        return self._metric_extraction

    @metric_extraction.setter
    def metric_extraction(self, metric_extraction):
        """
        Sets the metric_extraction of this StreamAction.

        :param metric_extraction: The metric_extraction of this StreamAction.
        :type: oci.log_analytics.models.MetricExtraction
        """
        self._metric_extraction = metric_extraction

    @property
    def saved_search_duration(self):
        """
        Gets the saved_search_duration of this StreamAction.
        The duration of data to be searched for SAVED_SEARCH tasks,
        used when the task fires to calculate the query time range.

        Duration in ISO 8601 extended format as described in
        https://en.wikipedia.org/wiki/ISO_8601#Durations.
        The value should be positive.
        The largest supported unit (as opposed to value) is D, e.g.  P14D (not P2W).

        There are restrictions on the maximum duration value relative to the task schedule
        value as specified in the following table.
           Schedule Interval Range          | Maximum Duration
        ----------------------------------- | -----------------
          5 Minutes     to 30 Minutes       |   1 hour  \"PT60M\"
         31 Minutes     to  1 Hour          |  12 hours \"PT720M\"
         1 Hour+1Minute to  1 Day           |   1 day   \"P1D\"
         1 Day+1Minute  to  1 Week-1Minute  |   7 days  \"P7D\"
         1 Week         to  2 Weeks         |  14 days  \"P14D\"
         greater than 2 Weeks               |  30 days  \"P30D\"

        If not specified, the duration will be based on the schedule. For example,
        if the schedule is every 5 minutes then the savedSearchDuration will be \"PT5M\";
        if the schedule is every 3 weeks then the savedSearchDuration will be \"P21D\".


        :return: The saved_search_duration of this StreamAction.
        :rtype: str
        """
        return self._saved_search_duration

    @saved_search_duration.setter
    def saved_search_duration(self, saved_search_duration):
        """
        Sets the saved_search_duration of this StreamAction.
        The duration of data to be searched for SAVED_SEARCH tasks,
        used when the task fires to calculate the query time range.

        Duration in ISO 8601 extended format as described in
        https://en.wikipedia.org/wiki/ISO_8601#Durations.
        The value should be positive.
        The largest supported unit (as opposed to value) is D, e.g.  P14D (not P2W).

        There are restrictions on the maximum duration value relative to the task schedule
        value as specified in the following table.
           Schedule Interval Range          | Maximum Duration
        ----------------------------------- | -----------------
          5 Minutes     to 30 Minutes       |   1 hour  \"PT60M\"
         31 Minutes     to  1 Hour          |  12 hours \"PT720M\"
         1 Hour+1Minute to  1 Day           |   1 day   \"P1D\"
         1 Day+1Minute  to  1 Week-1Minute  |   7 days  \"P7D\"
         1 Week         to  2 Weeks         |  14 days  \"P14D\"
         greater than 2 Weeks               |  30 days  \"P30D\"

        If not specified, the duration will be based on the schedule. For example,
        if the schedule is every 5 minutes then the savedSearchDuration will be \"PT5M\";
        if the schedule is every 3 weeks then the savedSearchDuration will be \"P21D\".


        :param saved_search_duration: The saved_search_duration of this StreamAction.
        :type: str
        """
        self._saved_search_duration = saved_search_duration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataTransferMediumDetails(object):
    """
    Note: Deprecated. Use the new resource model APIs instead.
    Data Transfer Medium details for the Migration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DataTransferMediumDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_link_details:
            The value to assign to the database_link_details property of this DataTransferMediumDetails.
        :type database_link_details: oci.database_migration.models.DatabaseLinkDetails

        :param object_storage_details:
            The value to assign to the object_storage_details property of this DataTransferMediumDetails.
        :type object_storage_details: oci.database_migration.models.ObjectStoreBucket

        """
        self.swagger_types = {
            'database_link_details': 'DatabaseLinkDetails',
            'object_storage_details': 'ObjectStoreBucket'
        }

        self.attribute_map = {
            'database_link_details': 'databaseLinkDetails',
            'object_storage_details': 'objectStorageDetails'
        }

        self._database_link_details = None
        self._object_storage_details = None

    @property
    def database_link_details(self):
        """
        Gets the database_link_details of this DataTransferMediumDetails.

        :return: The database_link_details of this DataTransferMediumDetails.
        :rtype: oci.database_migration.models.DatabaseLinkDetails
        """
        return self._database_link_details

    @database_link_details.setter
    def database_link_details(self, database_link_details):
        """
        Sets the database_link_details of this DataTransferMediumDetails.

        :param database_link_details: The database_link_details of this DataTransferMediumDetails.
        :type: oci.database_migration.models.DatabaseLinkDetails
        """
        self._database_link_details = database_link_details

    @property
    def object_storage_details(self):
        """
        Gets the object_storage_details of this DataTransferMediumDetails.

        :return: The object_storage_details of this DataTransferMediumDetails.
        :rtype: oci.database_migration.models.ObjectStoreBucket
        """
        return self._object_storage_details

    @object_storage_details.setter
    def object_storage_details(self, object_storage_details):
        """
        Sets the object_storage_details of this DataTransferMediumDetails.

        :param object_storage_details: The object_storage_details of this DataTransferMediumDetails.
        :type: oci.database_migration.models.ObjectStoreBucket
        """
        self._object_storage_details = object_storage_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsSourceMetric(object):
    """
    LogAnalyticsSourceMetric
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsSourceMetric object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_metric_source_enabled:
            The value to assign to the is_metric_source_enabled property of this LogAnalyticsSourceMetric.
        :type is_metric_source_enabled: bool

        :param metric_name:
            The value to assign to the metric_name property of this LogAnalyticsSourceMetric.
        :type metric_name: str

        :param source_name:
            The value to assign to the source_name property of this LogAnalyticsSourceMetric.
        :type source_name: str

        :param entity_type:
            The value to assign to the entity_type property of this LogAnalyticsSourceMetric.
        :type entity_type: str

        """
        self.swagger_types = {
            'is_metric_source_enabled': 'bool',
            'metric_name': 'str',
            'source_name': 'str',
            'entity_type': 'str'
        }

        self.attribute_map = {
            'is_metric_source_enabled': 'isMetricSourceEnabled',
            'metric_name': 'metricName',
            'source_name': 'sourceName',
            'entity_type': 'entityType'
        }

        self._is_metric_source_enabled = None
        self._metric_name = None
        self._source_name = None
        self._entity_type = None

    @property
    def is_metric_source_enabled(self):
        """
        Gets the is_metric_source_enabled of this LogAnalyticsSourceMetric.
        A flag specifying whether or not the metric source is enabled.


        :return: The is_metric_source_enabled of this LogAnalyticsSourceMetric.
        :rtype: bool
        """
        return self._is_metric_source_enabled

    @is_metric_source_enabled.setter
    def is_metric_source_enabled(self, is_metric_source_enabled):
        """
        Sets the is_metric_source_enabled of this LogAnalyticsSourceMetric.
        A flag specifying whether or not the metric source is enabled.


        :param is_metric_source_enabled: The is_metric_source_enabled of this LogAnalyticsSourceMetric.
        :type: bool
        """
        self._is_metric_source_enabled = is_metric_source_enabled

    @property
    def metric_name(self):
        """
        Gets the metric_name of this LogAnalyticsSourceMetric.
        The metric name.


        :return: The metric_name of this LogAnalyticsSourceMetric.
        :rtype: str
        """
        return self._metric_name

    @metric_name.setter
    def metric_name(self, metric_name):
        """
        Sets the metric_name of this LogAnalyticsSourceMetric.
        The metric name.


        :param metric_name: The metric_name of this LogAnalyticsSourceMetric.
        :type: str
        """
        self._metric_name = metric_name

    @property
    def source_name(self):
        """
        Gets the source_name of this LogAnalyticsSourceMetric.
        The source internal name.


        :return: The source_name of this LogAnalyticsSourceMetric.
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """
        Sets the source_name of this LogAnalyticsSourceMetric.
        The source internal name.


        :param source_name: The source_name of this LogAnalyticsSourceMetric.
        :type: str
        """
        self._source_name = source_name

    @property
    def entity_type(self):
        """
        Gets the entity_type of this LogAnalyticsSourceMetric.
        The entity type.


        :return: The entity_type of this LogAnalyticsSourceMetric.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this LogAnalyticsSourceMetric.
        The entity type.


        :param entity_type: The entity_type of this LogAnalyticsSourceMetric.
        :type: str
        """
        self._entity_type = entity_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_autonomous_database_base import CreateAutonomousDatabaseBase
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateRefreshableAutonomousDatabaseCloneDetails(CreateAutonomousDatabaseBase):
    """
    Details to create an Oracle Autonomous Database refreshable clone.
    """

    #: A constant which can be used with the refreshable_mode property of a CreateRefreshableAutonomousDatabaseCloneDetails.
    #: This constant has a value of "AUTOMATIC"
    REFRESHABLE_MODE_AUTOMATIC = "AUTOMATIC"

    #: A constant which can be used with the refreshable_mode property of a CreateRefreshableAutonomousDatabaseCloneDetails.
    #: This constant has a value of "MANUAL"
    REFRESHABLE_MODE_MANUAL = "MANUAL"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateRefreshableAutonomousDatabaseCloneDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database.models.CreateRefreshableAutonomousDatabaseCloneDetails.source` attribute
        of this class is ``CLONE_TO_REFRESHABLE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type compartment_id: str

        :param db_name:
            The value to assign to the db_name property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type db_name: str

        :param cpu_core_count:
            The value to assign to the cpu_core_count property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type cpu_core_count: int

        :param ocpu_count:
            The value to assign to the ocpu_count property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type ocpu_count: float

        :param db_workload:
            The value to assign to the db_workload property of this CreateRefreshableAutonomousDatabaseCloneDetails.
            Allowed values for this property are: "OLTP", "DW", "AJD", "APEX"
        :type db_workload: str

        :param data_storage_size_in_tbs:
            The value to assign to the data_storage_size_in_tbs property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type data_storage_size_in_tbs: int

        :param data_storage_size_in_gbs:
            The value to assign to the data_storage_size_in_gbs property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type data_storage_size_in_gbs: int

        :param is_free_tier:
            The value to assign to the is_free_tier property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type is_free_tier: bool

        :param kms_key_id:
            The value to assign to the kms_key_id property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type kms_key_id: str

        :param vault_id:
            The value to assign to the vault_id property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type vault_id: str

        :param admin_password:
            The value to assign to the admin_password property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type admin_password: str

        :param display_name:
            The value to assign to the display_name property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type display_name: str

        :param license_model:
            The value to assign to the license_model property of this CreateRefreshableAutonomousDatabaseCloneDetails.
            Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"
        :type license_model: str

        :param is_preview_version_with_service_terms_accepted:
            The value to assign to the is_preview_version_with_service_terms_accepted property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type is_preview_version_with_service_terms_accepted: bool

        :param is_auto_scaling_enabled:
            The value to assign to the is_auto_scaling_enabled property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type is_auto_scaling_enabled: bool

        :param is_dedicated:
            The value to assign to the is_dedicated property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type is_dedicated: bool

        :param autonomous_container_database_id:
            The value to assign to the autonomous_container_database_id property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type autonomous_container_database_id: str

        :param is_access_control_enabled:
            The value to assign to the is_access_control_enabled property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type is_access_control_enabled: bool

        :param whitelisted_ips:
            The value to assign to the whitelisted_ips property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type whitelisted_ips: list[str]

        :param are_primary_whitelisted_ips_used:
            The value to assign to the are_primary_whitelisted_ips_used property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type are_primary_whitelisted_ips_used: bool

        :param standby_whitelisted_ips:
            The value to assign to the standby_whitelisted_ips property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type standby_whitelisted_ips: list[str]

        :param is_data_guard_enabled:
            The value to assign to the is_data_guard_enabled property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type is_data_guard_enabled: bool

        :param subnet_id:
            The value to assign to the subnet_id property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type subnet_id: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type nsg_ids: list[str]

        :param private_endpoint_label:
            The value to assign to the private_endpoint_label property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type private_endpoint_label: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param db_version:
            The value to assign to the db_version property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type db_version: str

        :param source:
            The value to assign to the source property of this CreateRefreshableAutonomousDatabaseCloneDetails.
            Allowed values for this property are: "NONE", "DATABASE", "BACKUP_FROM_ID", "BACKUP_FROM_TIMESTAMP", "CLONE_TO_REFRESHABLE", "CROSS_REGION_DATAGUARD"
        :type source: str

        :param customer_contacts:
            The value to assign to the customer_contacts property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type customer_contacts: list[oci.database.models.CustomerContact]

        :param is_mtls_connection_required:
            The value to assign to the is_mtls_connection_required property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type is_mtls_connection_required: bool

        :param autonomous_maintenance_schedule_type:
            The value to assign to the autonomous_maintenance_schedule_type property of this CreateRefreshableAutonomousDatabaseCloneDetails.
            Allowed values for this property are: "EARLY", "REGULAR"
        :type autonomous_maintenance_schedule_type: str

        :param source_id:
            The value to assign to the source_id property of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type source_id: str

        :param refreshable_mode:
            The value to assign to the refreshable_mode property of this CreateRefreshableAutonomousDatabaseCloneDetails.
            Allowed values for this property are: "AUTOMATIC", "MANUAL"
        :type refreshable_mode: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'db_name': 'str',
            'cpu_core_count': 'int',
            'ocpu_count': 'float',
            'db_workload': 'str',
            'data_storage_size_in_tbs': 'int',
            'data_storage_size_in_gbs': 'int',
            'is_free_tier': 'bool',
            'kms_key_id': 'str',
            'vault_id': 'str',
            'admin_password': 'str',
            'display_name': 'str',
            'license_model': 'str',
            'is_preview_version_with_service_terms_accepted': 'bool',
            'is_auto_scaling_enabled': 'bool',
            'is_dedicated': 'bool',
            'autonomous_container_database_id': 'str',
            'is_access_control_enabled': 'bool',
            'whitelisted_ips': 'list[str]',
            'are_primary_whitelisted_ips_used': 'bool',
            'standby_whitelisted_ips': 'list[str]',
            'is_data_guard_enabled': 'bool',
            'subnet_id': 'str',
            'nsg_ids': 'list[str]',
            'private_endpoint_label': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'db_version': 'str',
            'source': 'str',
            'customer_contacts': 'list[CustomerContact]',
            'is_mtls_connection_required': 'bool',
            'autonomous_maintenance_schedule_type': 'str',
            'source_id': 'str',
            'refreshable_mode': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'db_name': 'dbName',
            'cpu_core_count': 'cpuCoreCount',
            'ocpu_count': 'ocpuCount',
            'db_workload': 'dbWorkload',
            'data_storage_size_in_tbs': 'dataStorageSizeInTBs',
            'data_storage_size_in_gbs': 'dataStorageSizeInGBs',
            'is_free_tier': 'isFreeTier',
            'kms_key_id': 'kmsKeyId',
            'vault_id': 'vaultId',
            'admin_password': 'adminPassword',
            'display_name': 'displayName',
            'license_model': 'licenseModel',
            'is_preview_version_with_service_terms_accepted': 'isPreviewVersionWithServiceTermsAccepted',
            'is_auto_scaling_enabled': 'isAutoScalingEnabled',
            'is_dedicated': 'isDedicated',
            'autonomous_container_database_id': 'autonomousContainerDatabaseId',
            'is_access_control_enabled': 'isAccessControlEnabled',
            'whitelisted_ips': 'whitelistedIps',
            'are_primary_whitelisted_ips_used': 'arePrimaryWhitelistedIpsUsed',
            'standby_whitelisted_ips': 'standbyWhitelistedIps',
            'is_data_guard_enabled': 'isDataGuardEnabled',
            'subnet_id': 'subnetId',
            'nsg_ids': 'nsgIds',
            'private_endpoint_label': 'privateEndpointLabel',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'db_version': 'dbVersion',
            'source': 'source',
            'customer_contacts': 'customerContacts',
            'is_mtls_connection_required': 'isMtlsConnectionRequired',
            'autonomous_maintenance_schedule_type': 'autonomousMaintenanceScheduleType',
            'source_id': 'sourceId',
            'refreshable_mode': 'refreshableMode'
        }

        self._compartment_id = None
        self._db_name = None
        self._cpu_core_count = None
        self._ocpu_count = None
        self._db_workload = None
        self._data_storage_size_in_tbs = None
        self._data_storage_size_in_gbs = None
        self._is_free_tier = None
        self._kms_key_id = None
        self._vault_id = None
        self._admin_password = None
        self._display_name = None
        self._license_model = None
        self._is_preview_version_with_service_terms_accepted = None
        self._is_auto_scaling_enabled = None
        self._is_dedicated = None
        self._autonomous_container_database_id = None
        self._is_access_control_enabled = None
        self._whitelisted_ips = None
        self._are_primary_whitelisted_ips_used = None
        self._standby_whitelisted_ips = None
        self._is_data_guard_enabled = None
        self._subnet_id = None
        self._nsg_ids = None
        self._private_endpoint_label = None
        self._freeform_tags = None
        self._defined_tags = None
        self._db_version = None
        self._source = None
        self._customer_contacts = None
        self._is_mtls_connection_required = None
        self._autonomous_maintenance_schedule_type = None
        self._source_id = None
        self._refreshable_mode = None
        self._source = 'CLONE_TO_REFRESHABLE'

    @property
    def source_id(self):
        """
        **[Required]** Gets the source_id of this CreateRefreshableAutonomousDatabaseCloneDetails.
        The `OCID`__ of the source Autonomous Database that you will clone to create a new Autonomous Database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The source_id of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :rtype: str
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """
        Sets the source_id of this CreateRefreshableAutonomousDatabaseCloneDetails.
        The `OCID`__ of the source Autonomous Database that you will clone to create a new Autonomous Database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param source_id: The source_id of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type: str
        """
        self._source_id = source_id

    @property
    def refreshable_mode(self):
        """
        Gets the refreshable_mode of this CreateRefreshableAutonomousDatabaseCloneDetails.
        The refresh mode of the clone. AUTOMATIC indicates that the clone is automatically being refreshed with data from the source Autonomous Database.

        Allowed values for this property are: "AUTOMATIC", "MANUAL"


        :return: The refreshable_mode of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :rtype: str
        """
        return self._refreshable_mode

    @refreshable_mode.setter
    def refreshable_mode(self, refreshable_mode):
        """
        Sets the refreshable_mode of this CreateRefreshableAutonomousDatabaseCloneDetails.
        The refresh mode of the clone. AUTOMATIC indicates that the clone is automatically being refreshed with data from the source Autonomous Database.


        :param refreshable_mode: The refreshable_mode of this CreateRefreshableAutonomousDatabaseCloneDetails.
        :type: str
        """
        allowed_values = ["AUTOMATIC", "MANUAL"]
        if not value_allowed_none_or_none_sentinel(refreshable_mode, allowed_values):
            raise ValueError(
                "Invalid value for `refreshable_mode`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._refreshable_mode = refreshable_mode

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDrgRouteDistributionDetails(object):
    """
    Details used to create a route distribution.
    """

    #: A constant which can be used with the distribution_type property of a CreateDrgRouteDistributionDetails.
    #: This constant has a value of "IMPORT"
    DISTRIBUTION_TYPE_IMPORT = "IMPORT"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDrgRouteDistributionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateDrgRouteDistributionDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateDrgRouteDistributionDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateDrgRouteDistributionDetails.
        :type freeform_tags: dict(str, str)

        :param drg_id:
            The value to assign to the drg_id property of this CreateDrgRouteDistributionDetails.
        :type drg_id: str

        :param distribution_type:
            The value to assign to the distribution_type property of this CreateDrgRouteDistributionDetails.
            Allowed values for this property are: "IMPORT"
        :type distribution_type: str

        """
        self.swagger_types = {
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'drg_id': 'str',
            'distribution_type': 'str'
        }

        self.attribute_map = {
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'drg_id': 'drgId',
            'distribution_type': 'distributionType'
        }

        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._drg_id = None
        self._distribution_type = None

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateDrgRouteDistributionDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateDrgRouteDistributionDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateDrgRouteDistributionDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateDrgRouteDistributionDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateDrgRouteDistributionDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this CreateDrgRouteDistributionDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateDrgRouteDistributionDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this CreateDrgRouteDistributionDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateDrgRouteDistributionDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateDrgRouteDistributionDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateDrgRouteDistributionDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateDrgRouteDistributionDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def drg_id(self):
        """
        **[Required]** Gets the drg_id of this CreateDrgRouteDistributionDetails.
        The `OCID`__ of the DRG the DRG route table belongs to.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The drg_id of this CreateDrgRouteDistributionDetails.
        :rtype: str
        """
        return self._drg_id

    @drg_id.setter
    def drg_id(self, drg_id):
        """
        Sets the drg_id of this CreateDrgRouteDistributionDetails.
        The `OCID`__ of the DRG the DRG route table belongs to.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param drg_id: The drg_id of this CreateDrgRouteDistributionDetails.
        :type: str
        """
        self._drg_id = drg_id

    @property
    def distribution_type(self):
        """
        **[Required]** Gets the distribution_type of this CreateDrgRouteDistributionDetails.
        Whether this distribution defines how routes get imported into route tables or exported through DRG Attachments

        Allowed values for this property are: "IMPORT"


        :return: The distribution_type of this CreateDrgRouteDistributionDetails.
        :rtype: str
        """
        return self._distribution_type

    @distribution_type.setter
    def distribution_type(self, distribution_type):
        """
        Sets the distribution_type of this CreateDrgRouteDistributionDetails.
        Whether this distribution defines how routes get imported into route tables or exported through DRG Attachments


        :param distribution_type: The distribution_type of this CreateDrgRouteDistributionDetails.
        :type: str
        """
        allowed_values = ["IMPORT"]
        if not value_allowed_none_or_none_sentinel(distribution_type, allowed_values):
            raise ValueError(
                "Invalid value for `distribution_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._distribution_type = distribution_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateIPSecTunnelEncryptionDomainDetails(object):
    """
    Request to enable a multi-encryption domain policy on the VPNaaS tunnel.
    There can't be more than 50 security associations in use at one time. See `Encryption domain for policy-based
    tunnels`__ for more.

    __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/ipsecencryptiondomains.htm#spi_policy_based_tunnel
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateIPSecTunnelEncryptionDomainDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param oracle_traffic_selector:
            The value to assign to the oracle_traffic_selector property of this CreateIPSecTunnelEncryptionDomainDetails.
        :type oracle_traffic_selector: list[str]

        :param cpe_traffic_selector:
            The value to assign to the cpe_traffic_selector property of this CreateIPSecTunnelEncryptionDomainDetails.
        :type cpe_traffic_selector: list[str]

        """
        self.swagger_types = {
            'oracle_traffic_selector': 'list[str]',
            'cpe_traffic_selector': 'list[str]'
        }

        self.attribute_map = {
            'oracle_traffic_selector': 'oracleTrafficSelector',
            'cpe_traffic_selector': 'cpeTrafficSelector'
        }

        self._oracle_traffic_selector = None
        self._cpe_traffic_selector = None

    @property
    def oracle_traffic_selector(self):
        """
        Gets the oracle_traffic_selector of this CreateIPSecTunnelEncryptionDomainDetails.
        Lists IPv4 or IPv6-enabled subnets in your Oracle tenancy.


        :return: The oracle_traffic_selector of this CreateIPSecTunnelEncryptionDomainDetails.
        :rtype: list[str]
        """
        return self._oracle_traffic_selector

    @oracle_traffic_selector.setter
    def oracle_traffic_selector(self, oracle_traffic_selector):
        """
        Sets the oracle_traffic_selector of this CreateIPSecTunnelEncryptionDomainDetails.
        Lists IPv4 or IPv6-enabled subnets in your Oracle tenancy.


        :param oracle_traffic_selector: The oracle_traffic_selector of this CreateIPSecTunnelEncryptionDomainDetails.
        :type: list[str]
        """
        self._oracle_traffic_selector = oracle_traffic_selector

    @property
    def cpe_traffic_selector(self):
        """
        Gets the cpe_traffic_selector of this CreateIPSecTunnelEncryptionDomainDetails.
        Lists IPv4 or IPv6-enabled subnets in your on-premises network.


        :return: The cpe_traffic_selector of this CreateIPSecTunnelEncryptionDomainDetails.
        :rtype: list[str]
        """
        return self._cpe_traffic_selector

    @cpe_traffic_selector.setter
    def cpe_traffic_selector(self, cpe_traffic_selector):
        """
        Sets the cpe_traffic_selector of this CreateIPSecTunnelEncryptionDomainDetails.
        Lists IPv4 or IPv6-enabled subnets in your on-premises network.


        :param cpe_traffic_selector: The cpe_traffic_selector of this CreateIPSecTunnelEncryptionDomainDetails.
        :type: list[str]
        """
        self._cpe_traffic_selector = cpe_traffic_selector

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AlarmSummary(object):
    """
    A summary of properties for the specified alarm.
    For information about alarms, see `Alarms Overview`__.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
    talk to an administrator. If you're an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    For information about endpoints and signing API requests, see
    `About the API`__. For information about available SDKs and tools, see
    `SDKS and Other Tools`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#AlarmsOverview
    __ https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm
    __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm
    __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/sdks.htm
    """

    #: A constant which can be used with the severity property of a AlarmSummary.
    #: This constant has a value of "CRITICAL"
    SEVERITY_CRITICAL = "CRITICAL"

    #: A constant which can be used with the severity property of a AlarmSummary.
    #: This constant has a value of "ERROR"
    SEVERITY_ERROR = "ERROR"

    #: A constant which can be used with the severity property of a AlarmSummary.
    #: This constant has a value of "WARNING"
    SEVERITY_WARNING = "WARNING"

    #: A constant which can be used with the severity property of a AlarmSummary.
    #: This constant has a value of "INFO"
    SEVERITY_INFO = "INFO"

    def __init__(self, **kwargs):
        """
        Initializes a new AlarmSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AlarmSummary.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this AlarmSummary.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this AlarmSummary.
        :type compartment_id: str

        :param metric_compartment_id:
            The value to assign to the metric_compartment_id property of this AlarmSummary.
        :type metric_compartment_id: str

        :param namespace:
            The value to assign to the namespace property of this AlarmSummary.
        :type namespace: str

        :param query:
            The value to assign to the query property of this AlarmSummary.
        :type query: str

        :param severity:
            The value to assign to the severity property of this AlarmSummary.
            Allowed values for this property are: "CRITICAL", "ERROR", "WARNING", "INFO", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type severity: str

        :param destinations:
            The value to assign to the destinations property of this AlarmSummary.
        :type destinations: list[str]

        :param suppression:
            The value to assign to the suppression property of this AlarmSummary.
        :type suppression: oci.monitoring.models.Suppression

        :param is_enabled:
            The value to assign to the is_enabled property of this AlarmSummary.
        :type is_enabled: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this AlarmSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this AlarmSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AlarmSummary.
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'metric_compartment_id': 'str',
            'namespace': 'str',
            'query': 'str',
            'severity': 'str',
            'destinations': 'list[str]',
            'suppression': 'Suppression',
            'is_enabled': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'metric_compartment_id': 'metricCompartmentId',
            'namespace': 'namespace',
            'query': 'query',
            'severity': 'severity',
            'destinations': 'destinations',
            'suppression': 'suppression',
            'is_enabled': 'isEnabled',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'lifecycle_state': 'lifecycleState'
        }

        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._metric_compartment_id = None
        self._namespace = None
        self._query = None
        self._severity = None
        self._destinations = None
        self._suppression = None
        self._is_enabled = None
        self._freeform_tags = None
        self._defined_tags = None
        self._lifecycle_state = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this AlarmSummary.
        The `OCID`__ of the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this AlarmSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AlarmSummary.
        The `OCID`__ of the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this AlarmSummary.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this AlarmSummary.
        A user-friendly name for the alarm. It does not have to be unique, and it's changeable.

        This name is sent as the title for notifications related to this alarm.

        Example: `High CPU Utilization`


        :return: The display_name of this AlarmSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this AlarmSummary.
        A user-friendly name for the alarm. It does not have to be unique, and it's changeable.

        This name is sent as the title for notifications related to this alarm.

        Example: `High CPU Utilization`


        :param display_name: The display_name of this AlarmSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this AlarmSummary.
        The `OCID`__ of the compartment containing the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this AlarmSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this AlarmSummary.
        The `OCID`__ of the compartment containing the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this AlarmSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def metric_compartment_id(self):
        """
        **[Required]** Gets the metric_compartment_id of this AlarmSummary.
        The `OCID`__ of the compartment containing the metric
        being evaluated by the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The metric_compartment_id of this AlarmSummary.
        :rtype: str
        """
        return self._metric_compartment_id

    @metric_compartment_id.setter
    def metric_compartment_id(self, metric_compartment_id):
        """
        Sets the metric_compartment_id of this AlarmSummary.
        The `OCID`__ of the compartment containing the metric
        being evaluated by the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param metric_compartment_id: The metric_compartment_id of this AlarmSummary.
        :type: str
        """
        self._metric_compartment_id = metric_compartment_id

    @property
    def namespace(self):
        """
        **[Required]** Gets the namespace of this AlarmSummary.
        The source service or application emitting the metric that is evaluated by the alarm.

        Example: `oci_computeagent`


        :return: The namespace of this AlarmSummary.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this AlarmSummary.
        The source service or application emitting the metric that is evaluated by the alarm.

        Example: `oci_computeagent`


        :param namespace: The namespace of this AlarmSummary.
        :type: str
        """
        self._namespace = namespace

    @property
    def query(self):
        """
        **[Required]** Gets the query of this AlarmSummary.
        The Monitoring Query Language (MQL) expression to evaluate for the alarm. The Alarms feature of
        the Monitoring service interprets results for each returned time series as Boolean values,
        where zero represents false and a non-zero value represents true. A true value means that the trigger
        rule condition has been met. The query must specify a metric, statistic, interval, and trigger
        rule (threshold or absence). Supported values for interval depend on the specified time range. More
        interval values are supported for smaller time ranges. Supported grouping functions: `grouping()`, `groupBy()`.
        For details about Monitoring Query Language (MQL), see `Monitoring Query Language (MQL) Reference`__.
        For available dimensions, review the metric definition for the supported service.
        See `Supported Services`__.

        Example of threshold alarm:

          -----

            CpuUtilization[1m]{availabilityDomain=\"cumS:PHX-AD-1\"}.groupBy(availabilityDomain).percentile(0.9) > 85

          -----

        Example of absence alarm:

          -----

            CpuUtilization[1m]{availabilityDomain=\"cumS:PHX-AD-1\"}.absent()

          -----

        __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Reference/mql.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#SupportedServices


        :return: The query of this AlarmSummary.
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """
        Sets the query of this AlarmSummary.
        The Monitoring Query Language (MQL) expression to evaluate for the alarm. The Alarms feature of
        the Monitoring service interprets results for each returned time series as Boolean values,
        where zero represents false and a non-zero value represents true. A true value means that the trigger
        rule condition has been met. The query must specify a metric, statistic, interval, and trigger
        rule (threshold or absence). Supported values for interval depend on the specified time range. More
        interval values are supported for smaller time ranges. Supported grouping functions: `grouping()`, `groupBy()`.
        For details about Monitoring Query Language (MQL), see `Monitoring Query Language (MQL) Reference`__.
        For available dimensions, review the metric definition for the supported service.
        See `Supported Services`__.

        Example of threshold alarm:

          -----

            CpuUtilization[1m]{availabilityDomain=\"cumS:PHX-AD-1\"}.groupBy(availabilityDomain).percentile(0.9) > 85

          -----

        Example of absence alarm:

          -----

            CpuUtilization[1m]{availabilityDomain=\"cumS:PHX-AD-1\"}.absent()

          -----

        __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Reference/mql.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#SupportedServices


        :param query: The query of this AlarmSummary.
        :type: str
        """
        self._query = query

    @property
    def severity(self):
        """
        **[Required]** Gets the severity of this AlarmSummary.
        The perceived severity of the alarm with regard to the affected system.

        Example: `CRITICAL`

        Allowed values for this property are: "CRITICAL", "ERROR", "WARNING", "INFO", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The severity of this AlarmSummary.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """
        Sets the severity of this AlarmSummary.
        The perceived severity of the alarm with regard to the affected system.

        Example: `CRITICAL`


        :param severity: The severity of this AlarmSummary.
        :type: str
        """
        allowed_values = ["CRITICAL", "ERROR", "WARNING", "INFO"]
        if not value_allowed_none_or_none_sentinel(severity, allowed_values):
            severity = 'UNKNOWN_ENUM_VALUE'
        self._severity = severity

    @property
    def destinations(self):
        """
        **[Required]** Gets the destinations of this AlarmSummary.
        A list of destinations to which the notifications for this alarm will be delivered.
        Each destination is represented by an `OCID`__ related to the supported destination service.
        For example, a destination using the Notifications service is represented by a topic OCID.
        Supported destination services: Notifications Service. Limit: One destination per supported destination service.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The destinations of this AlarmSummary.
        :rtype: list[str]
        """
        return self._destinations

    @destinations.setter
    def destinations(self, destinations):
        """
        Sets the destinations of this AlarmSummary.
        A list of destinations to which the notifications for this alarm will be delivered.
        Each destination is represented by an `OCID`__ related to the supported destination service.
        For example, a destination using the Notifications service is represented by a topic OCID.
        Supported destination services: Notifications Service. Limit: One destination per supported destination service.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param destinations: The destinations of this AlarmSummary.
        :type: list[str]
        """
        self._destinations = destinations

    @property
    def suppression(self):
        """
        Gets the suppression of this AlarmSummary.
        The configuration details for suppressing an alarm.


        :return: The suppression of this AlarmSummary.
        :rtype: oci.monitoring.models.Suppression
        """
        return self._suppression

    @suppression.setter
    def suppression(self, suppression):
        """
        Sets the suppression of this AlarmSummary.
        The configuration details for suppressing an alarm.


        :param suppression: The suppression of this AlarmSummary.
        :type: oci.monitoring.models.Suppression
        """
        self._suppression = suppression

    @property
    def is_enabled(self):
        """
        **[Required]** Gets the is_enabled of this AlarmSummary.
        Whether the alarm is enabled.

        Example: `true`


        :return: The is_enabled of this AlarmSummary.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this AlarmSummary.
        Whether the alarm is enabled.

        Example: `true`


        :param is_enabled: The is_enabled of this AlarmSummary.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this AlarmSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"Department\": \"Finance\"}`


        :return: The freeform_tags of this AlarmSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this AlarmSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"Department\": \"Finance\"}`


        :param freeform_tags: The freeform_tags of this AlarmSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this AlarmSummary.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`


        :return: The defined_tags of this AlarmSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this AlarmSummary.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`


        :param defined_tags: The defined_tags of this AlarmSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this AlarmSummary.
        The current lifecycle state of the alarm.

        Example: `DELETED`


        :return: The lifecycle_state of this AlarmSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this AlarmSummary.
        The current lifecycle state of the alarm.

        Example: `DELETED`


        :param lifecycle_state: The lifecycle_state of this AlarmSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseCredentialDetails(object):
    """
    Data for the credential used to connect to the database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseCredentialDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param user_name:
            The value to assign to the user_name property of this DatabaseCredentialDetails.
        :type user_name: str

        :param password_secret_id:
            The value to assign to the password_secret_id property of this DatabaseCredentialDetails.
        :type password_secret_id: str

        """
        self.swagger_types = {
            'user_name': 'str',
            'password_secret_id': 'str'
        }

        self.attribute_map = {
            'user_name': 'userName',
            'password_secret_id': 'passwordSecretId'
        }

        self._user_name = None
        self._password_secret_id = None

    @property
    def user_name(self):
        """
        **[Required]** Gets the user_name of this DatabaseCredentialDetails.
        The name of the Oracle Database user that will be used to connect to the database.


        :return: The user_name of this DatabaseCredentialDetails.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this DatabaseCredentialDetails.
        The name of the Oracle Database user that will be used to connect to the database.


        :param user_name: The user_name of this DatabaseCredentialDetails.
        :type: str
        """
        self._user_name = user_name

    @property
    def password_secret_id(self):
        """
        **[Required]** Gets the password_secret_id of this DatabaseCredentialDetails.
        The `OCID`__ of the Oracle Cloud Infrastructure `secret`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts


        :return: The password_secret_id of this DatabaseCredentialDetails.
        :rtype: str
        """
        return self._password_secret_id

    @password_secret_id.setter
    def password_secret_id(self, password_secret_id):
        """
        Sets the password_secret_id of this DatabaseCredentialDetails.
        The `OCID`__ of the Oracle Cloud Infrastructure `secret`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts


        :param password_secret_id: The password_secret_id of this DatabaseCredentialDetails.
        :type: str
        """
        self._password_secret_id = password_secret_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateTermDetails(object):
    """
    Properties used in term create operations.
    """

    #: A constant which can be used with the workflow_status property of a CreateTermDetails.
    #: This constant has a value of "NEW"
    WORKFLOW_STATUS_NEW = "NEW"

    #: A constant which can be used with the workflow_status property of a CreateTermDetails.
    #: This constant has a value of "APPROVED"
    WORKFLOW_STATUS_APPROVED = "APPROVED"

    #: A constant which can be used with the workflow_status property of a CreateTermDetails.
    #: This constant has a value of "UNDER_REVIEW"
    WORKFLOW_STATUS_UNDER_REVIEW = "UNDER_REVIEW"

    #: A constant which can be used with the workflow_status property of a CreateTermDetails.
    #: This constant has a value of "ESCALATED"
    WORKFLOW_STATUS_ESCALATED = "ESCALATED"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateTermDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateTermDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateTermDetails.
        :type description: str

        :param is_allowed_to_have_child_terms:
            The value to assign to the is_allowed_to_have_child_terms property of this CreateTermDetails.
        :type is_allowed_to_have_child_terms: bool

        :param parent_term_key:
            The value to assign to the parent_term_key property of this CreateTermDetails.
        :type parent_term_key: str

        :param owner:
            The value to assign to the owner property of this CreateTermDetails.
        :type owner: str

        :param workflow_status:
            The value to assign to the workflow_status property of this CreateTermDetails.
            Allowed values for this property are: "NEW", "APPROVED", "UNDER_REVIEW", "ESCALATED"
        :type workflow_status: str

        :param custom_property_members:
            The value to assign to the custom_property_members property of this CreateTermDetails.
        :type custom_property_members: list[oci.data_catalog.models.CustomPropertySetUsage]

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'is_allowed_to_have_child_terms': 'bool',
            'parent_term_key': 'str',
            'owner': 'str',
            'workflow_status': 'str',
            'custom_property_members': 'list[CustomPropertySetUsage]'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'is_allowed_to_have_child_terms': 'isAllowedToHaveChildTerms',
            'parent_term_key': 'parentTermKey',
            'owner': 'owner',
            'workflow_status': 'workflowStatus',
            'custom_property_members': 'customPropertyMembers'
        }

        self._display_name = None
        self._description = None
        self._is_allowed_to_have_child_terms = None
        self._parent_term_key = None
        self._owner = None
        self._workflow_status = None
        self._custom_property_members = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateTermDetails.
        A user-friendly display name. Is changeable. The combination of 'displayName' and 'parentTermKey'
        must be unique. Avoid entering confidential information.


        :return: The display_name of this CreateTermDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateTermDetails.
        A user-friendly display name. Is changeable. The combination of 'displayName' and 'parentTermKey'
        must be unique. Avoid entering confidential information.


        :param display_name: The display_name of this CreateTermDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateTermDetails.
        Detailed description of the term.


        :return: The description of this CreateTermDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateTermDetails.
        Detailed description of the term.


        :param description: The description of this CreateTermDetails.
        :type: str
        """
        self._description = description

    @property
    def is_allowed_to_have_child_terms(self):
        """
        Gets the is_allowed_to_have_child_terms of this CreateTermDetails.
        Indicates whether a term may contain child terms.


        :return: The is_allowed_to_have_child_terms of this CreateTermDetails.
        :rtype: bool
        """
        return self._is_allowed_to_have_child_terms

    @is_allowed_to_have_child_terms.setter
    def is_allowed_to_have_child_terms(self, is_allowed_to_have_child_terms):
        """
        Sets the is_allowed_to_have_child_terms of this CreateTermDetails.
        Indicates whether a term may contain child terms.


        :param is_allowed_to_have_child_terms: The is_allowed_to_have_child_terms of this CreateTermDetails.
        :type: bool
        """
        self._is_allowed_to_have_child_terms = is_allowed_to_have_child_terms

    @property
    def parent_term_key(self):
        """
        Gets the parent_term_key of this CreateTermDetails.
        The terms parent term key. Will be null if the term has no parent term.


        :return: The parent_term_key of this CreateTermDetails.
        :rtype: str
        """
        return self._parent_term_key

    @parent_term_key.setter
    def parent_term_key(self, parent_term_key):
        """
        Sets the parent_term_key of this CreateTermDetails.
        The terms parent term key. Will be null if the term has no parent term.


        :param parent_term_key: The parent_term_key of this CreateTermDetails.
        :type: str
        """
        self._parent_term_key = parent_term_key

    @property
    def owner(self):
        """
        Gets the owner of this CreateTermDetails.
        OCID of the user who is the owner of this business terminology.


        :return: The owner of this CreateTermDetails.
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this CreateTermDetails.
        OCID of the user who is the owner of this business terminology.


        :param owner: The owner of this CreateTermDetails.
        :type: str
        """
        self._owner = owner

    @property
    def workflow_status(self):
        """
        Gets the workflow_status of this CreateTermDetails.
        Status of the approval process workflow for this business term in the glossary.

        Allowed values for this property are: "NEW", "APPROVED", "UNDER_REVIEW", "ESCALATED"


        :return: The workflow_status of this CreateTermDetails.
        :rtype: str
        """
        return self._workflow_status

    @workflow_status.setter
    def workflow_status(self, workflow_status):
        """
        Sets the workflow_status of this CreateTermDetails.
        Status of the approval process workflow for this business term in the glossary.


        :param workflow_status: The workflow_status of this CreateTermDetails.
        :type: str
        """
        allowed_values = ["NEW", "APPROVED", "UNDER_REVIEW", "ESCALATED"]
        if not value_allowed_none_or_none_sentinel(workflow_status, allowed_values):
            raise ValueError(
                "Invalid value for `workflow_status`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._workflow_status = workflow_status

    @property
    def custom_property_members(self):
        """
        Gets the custom_property_members of this CreateTermDetails.
        The list of customized properties along with the values for this object


        :return: The custom_property_members of this CreateTermDetails.
        :rtype: list[oci.data_catalog.models.CustomPropertySetUsage]
        """
        return self._custom_property_members

    @custom_property_members.setter
    def custom_property_members(self, custom_property_members):
        """
        Sets the custom_property_members of this CreateTermDetails.
        The list of customized properties along with the values for this object


        :param custom_property_members: The custom_property_members of this CreateTermDetails.
        :type: list[oci.data_catalog.models.CustomPropertySetUsage]
        """
        self._custom_property_members = custom_property_members

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ProcessRecommendationDetails(object):
    """
    Details of recommendation to be processed.
    """

    #: A constant which can be used with the recommendation_status property of a ProcessRecommendationDetails.
    #: This constant has a value of "ACCEPTED"
    RECOMMENDATION_STATUS_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the recommendation_status property of a ProcessRecommendationDetails.
    #: This constant has a value of "REJECTED"
    RECOMMENDATION_STATUS_REJECTED = "REJECTED"

    #: A constant which can be used with the recommendation_status property of a ProcessRecommendationDetails.
    #: This constant has a value of "INFERRED"
    RECOMMENDATION_STATUS_INFERRED = "INFERRED"

    def __init__(self, **kwargs):
        """
        Initializes a new ProcessRecommendationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param recommendation_key:
            The value to assign to the recommendation_key property of this ProcessRecommendationDetails.
        :type recommendation_key: str

        :param recommendation_status:
            The value to assign to the recommendation_status property of this ProcessRecommendationDetails.
            Allowed values for this property are: "ACCEPTED", "REJECTED", "INFERRED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type recommendation_status: str

        :param properties:
            The value to assign to the properties property of this ProcessRecommendationDetails.
        :type properties: dict(str, dict(str, str))

        """
        self.swagger_types = {
            'recommendation_key': 'str',
            'recommendation_status': 'str',
            'properties': 'dict(str, dict(str, str))'
        }

        self.attribute_map = {
            'recommendation_key': 'recommendationKey',
            'recommendation_status': 'recommendationStatus',
            'properties': 'properties'
        }

        self._recommendation_key = None
        self._recommendation_status = None
        self._properties = None

    @property
    def recommendation_key(self):
        """
        **[Required]** Gets the recommendation_key of this ProcessRecommendationDetails.
        Unique identifier of the recommendation.


        :return: The recommendation_key of this ProcessRecommendationDetails.
        :rtype: str
        """
        return self._recommendation_key

    @recommendation_key.setter
    def recommendation_key(self, recommendation_key):
        """
        Sets the recommendation_key of this ProcessRecommendationDetails.
        Unique identifier of the recommendation.


        :param recommendation_key: The recommendation_key of this ProcessRecommendationDetails.
        :type: str
        """
        self._recommendation_key = recommendation_key

    @property
    def recommendation_status(self):
        """
        **[Required]** Gets the recommendation_status of this ProcessRecommendationDetails.
        The status of a recommendation.

        Allowed values for this property are: "ACCEPTED", "REJECTED", "INFERRED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The recommendation_status of this ProcessRecommendationDetails.
        :rtype: str
        """
        return self._recommendation_status

    @recommendation_status.setter
    def recommendation_status(self, recommendation_status):
        """
        Sets the recommendation_status of this ProcessRecommendationDetails.
        The status of a recommendation.


        :param recommendation_status: The recommendation_status of this ProcessRecommendationDetails.
        :type: str
        """
        allowed_values = ["ACCEPTED", "REJECTED", "INFERRED"]
        if not value_allowed_none_or_none_sentinel(recommendation_status, allowed_values):
            recommendation_status = 'UNKNOWN_ENUM_VALUE'
        self._recommendation_status = recommendation_status

    @property
    def properties(self):
        """
        Gets the properties of this ProcessRecommendationDetails.
        A map of maps that contains additional properties which are specific to the associated objects.
        Each associated object defines it's set of required and optional properties.
        Example: `{
                    \"DataEntity\": {
                      \"parentId\": \"entityId\"
                    },
                    \"Term\": {
                      \"parentId\": \"glossaryId\"
                    }
                  }`


        :return: The properties of this ProcessRecommendationDetails.
        :rtype: dict(str, dict(str, str))
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this ProcessRecommendationDetails.
        A map of maps that contains additional properties which are specific to the associated objects.
        Each associated object defines it's set of required and optional properties.
        Example: `{
                    \"DataEntity\": {
                      \"parentId\": \"entityId\"
                    },
                    \"Term\": {
                      \"parentId\": \"glossaryId\"
                    }
                  }`


        :param properties: The properties of this ProcessRecommendationDetails.
        :type: dict(str, dict(str, str))
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RoverWorkload(object):
    """
    Information about a RoverWorkload.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RoverWorkload object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this RoverWorkload.
        :type name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this RoverWorkload.
        :type compartment_id: str

        :param id:
            The value to assign to the id property of this RoverWorkload.
        :type id: str

        :param size:
            The value to assign to the size property of this RoverWorkload.
        :type size: str

        :param object_count:
            The value to assign to the object_count property of this RoverWorkload.
        :type object_count: str

        :param prefix:
            The value to assign to the prefix property of this RoverWorkload.
        :type prefix: str

        :param range_start:
            The value to assign to the range_start property of this RoverWorkload.
        :type range_start: str

        :param range_end:
            The value to assign to the range_end property of this RoverWorkload.
        :type range_end: str

        :param workload_type:
            The value to assign to the workload_type property of this RoverWorkload.
        :type workload_type: str

        :param work_request_id:
            The value to assign to the work_request_id property of this RoverWorkload.
        :type work_request_id: str

        """
        self.swagger_types = {
            'name': 'str',
            'compartment_id': 'str',
            'id': 'str',
            'size': 'str',
            'object_count': 'str',
            'prefix': 'str',
            'range_start': 'str',
            'range_end': 'str',
            'workload_type': 'str',
            'work_request_id': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'compartment_id': 'compartmentId',
            'id': 'id',
            'size': 'size',
            'object_count': 'objectCount',
            'prefix': 'prefix',
            'range_start': 'rangeStart',
            'range_end': 'rangeEnd',
            'workload_type': 'workloadType',
            'work_request_id': 'workRequestId'
        }

        self._name = None
        self._compartment_id = None
        self._id = None
        self._size = None
        self._object_count = None
        self._prefix = None
        self._range_start = None
        self._range_end = None
        self._workload_type = None
        self._work_request_id = None

    @property
    def name(self):
        """
        Gets the name of this RoverWorkload.
        Name of the Rover Workload


        :return: The name of this RoverWorkload.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this RoverWorkload.
        Name of the Rover Workload


        :param name: The name of this RoverWorkload.
        :type: str
        """
        self._name = name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this RoverWorkload.
        The OCID of the compartment containing the workload.


        :return: The compartment_id of this RoverWorkload.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this RoverWorkload.
        The OCID of the compartment containing the workload.


        :param compartment_id: The compartment_id of this RoverWorkload.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def id(self):
        """
        **[Required]** Gets the id of this RoverWorkload.
        The Unique Oracle ID (OCID) that is immutable on creation.


        :return: The id of this RoverWorkload.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RoverWorkload.
        The Unique Oracle ID (OCID) that is immutable on creation.


        :param id: The id of this RoverWorkload.
        :type: str
        """
        self._id = id

    @property
    def size(self):
        """
        Gets the size of this RoverWorkload.
        Size of the workload.


        :return: The size of this RoverWorkload.
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this RoverWorkload.
        Size of the workload.


        :param size: The size of this RoverWorkload.
        :type: str
        """
        self._size = size

    @property
    def object_count(self):
        """
        Gets the object_count of this RoverWorkload.
        Number of objects in a workload.


        :return: The object_count of this RoverWorkload.
        :rtype: str
        """
        return self._object_count

    @object_count.setter
    def object_count(self, object_count):
        """
        Sets the object_count of this RoverWorkload.
        Number of objects in a workload.


        :param object_count: The object_count of this RoverWorkload.
        :type: str
        """
        self._object_count = object_count

    @property
    def prefix(self):
        """
        Gets the prefix of this RoverWorkload.
        Prefix to filter objects in case it is a bucket.


        :return: The prefix of this RoverWorkload.
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """
        Sets the prefix of this RoverWorkload.
        Prefix to filter objects in case it is a bucket.


        :param prefix: The prefix of this RoverWorkload.
        :type: str
        """
        self._prefix = prefix

    @property
    def range_start(self):
        """
        Gets the range_start of this RoverWorkload.
        Start of the range in a bucket.


        :return: The range_start of this RoverWorkload.
        :rtype: str
        """
        return self._range_start

    @range_start.setter
    def range_start(self, range_start):
        """
        Sets the range_start of this RoverWorkload.
        Start of the range in a bucket.


        :param range_start: The range_start of this RoverWorkload.
        :type: str
        """
        self._range_start = range_start

    @property
    def range_end(self):
        """
        Gets the range_end of this RoverWorkload.
        End of the range in a bucket.


        :return: The range_end of this RoverWorkload.
        :rtype: str
        """
        return self._range_end

    @range_end.setter
    def range_end(self, range_end):
        """
        Sets the range_end of this RoverWorkload.
        End of the range in a bucket.


        :param range_end: The range_end of this RoverWorkload.
        :type: str
        """
        self._range_end = range_end

    @property
    def workload_type(self):
        """
        **[Required]** Gets the workload_type of this RoverWorkload.
        The type of workload


        :return: The workload_type of this RoverWorkload.
        :rtype: str
        """
        return self._workload_type

    @workload_type.setter
    def workload_type(self, workload_type):
        """
        Sets the workload_type of this RoverWorkload.
        The type of workload


        :param workload_type: The workload_type of this RoverWorkload.
        :type: str
        """
        self._workload_type = workload_type

    @property
    def work_request_id(self):
        """
        Gets the work_request_id of this RoverWorkload.
        The compute work request id to track progress of custom image exports.


        :return: The work_request_id of this RoverWorkload.
        :rtype: str
        """
        return self._work_request_id

    @work_request_id.setter
    def work_request_id(self, work_request_id):
        """
        Sets the work_request_id of this RoverWorkload.
        The compute work request id to track progress of custom image exports.


        :param work_request_id: The work_request_id of this RoverWorkload.
        :type: str
        """
        self._work_request_id = work_request_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
